@@ -1,14 +1,14 @@
-#!/bin/bash
+#!/bin/sh
 
 ## @file
 ## @brief Camera import hook script
 ##
 
-if [ "$ACTION" == "download" ]
+if [ "$ACTION" = "download" ]
 then
-	echo "$ARGUMENT" >> /tmp/geeqie-camera-import-files
+	printf '%s\n' "$ARGUMENT" >> /tmp/geeqie-camera-import-files
 
-elif [ "$ACTION" == "stop" ]
+elif [ "$ACTION" = "stop" ]
 then
 	zenity --info --title="Geeqie camera download" --text="Import ended" --width=200 --timeout=5 --window-icon=usr/local/share/pixmaps/geeqie.png 2>/dev/null 
 	if [ -f /tmp/geeqie-camera-import-files ]
